#
# spec file for package datamash
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# bypass https://bugzilla.opensuse.org/show_bug.cgi?id=1149348
%ifarch ppc64le ppc64 aarch64
%define _lto_cflags %{nil}
%endif
Name:           datamash
Version:        1.8
Release:        1.9
Summary:        Statistical, numerical and textual operations in the command line
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.gnu.org/software/datamash/
Source:         https://ftp.gnu.org/gnu/datamash/%{name}-%{version}.tar.gz
Source2:        https://ftp.gnu.org/gnu/datamash/%{name}-%{version}.tar.gz.sig
# "Timothy Rice (Yubikey 5 Nano 13139911) <trice@posteo.net>" from https://ftp.gnu.org/gnu/gnu-keyring.gpg
Source3:        datamash.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
Requires(post): %{install_info_prereq}
Requires(preun):%{install_info_prereq}

%description
GNU datamash is a command-line program which performs basic numeric,
textual and statistical operations on input textual data files.

%prep
%setup -q

%build
%configure \
	--docdir=%{_docdir}/%{name} \
	--with-openssl=yes \
	--with-packager="%{vendor}" \
	--with-packager-version="%{distribution} %{version}-%{release}" \
	--with-packager-bug-reports="%{packager}" \
	--with-bash-completion-dir=no
%make_build

%install
%make_install
%find_lang %{name}

%check
%make_build check

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -f %{name}.lang
%license COPYING
%doc ChangeLog README AUTHORS THANKS
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}
%{_infodir}/%{name}.info%{?ext_info}
%{_datadir}/%{name}

%changelog
* Thu Jul 28 2022 Dirk Müller <dmueller@suse.com>
- update to 1.8:
  * * Changes in Behavior
    Schedule -f/--full combined with non-linewise operations for deprecation.
    In a future release, -f/--full will only be usable with operations where
    it makes sense. For now, we print a warning to stderr when -f/--full is
    used with non-linewise operations, and such usage will no longer be
    supported.
  * The bin operation now uses more intuitive bins. Previously, a command
    such as `datamash bin 1 <<< -0` would output -100; and -100 did not fall
    in its own bin. We now require all bins to take the form `[nx,(n+1)x)`
    with integer n and bin width x. We discard the sign on -0 and gate such
    inputs into the [0,x) bin.
  * Operations taking more than one argument now provide more complete output
    with --header-out. Previously, an operation such as `pcov x:y` would
    produce an output header like `pcov(y)`, discarding the `x`. The new
    behavior will output header `pcov(x,y)`.
  * datamash(1) no longer ignores --output-delimiter with the rmdup operation.
  * * New Features
  * New datamash option --sort-cmd argument to specify the program used
    by the -s option to sort input, plus enhancements to the security and
    portability of building sort command lines.
  * New datamash option -c/--collapse-delimiter=X argument uses character
    X instead of comma between values in collapse and unique lists.
  * New datamash operations: mean square (ms) and root mean square (rms).
  * Decorate now supports sorting IP addresses of both versions 4 and 6
    together. IPv4 addresses are logically converted to IPv6 addresses,
    either as IPv4-Mapped (ipv6v4map) or IPv4-Compatible (ipv6v4comp)
    addresses.
  * Add two command aliases:
    'echo' may now be used instead of 'cut'.
    'uniq' may now be used instead of 'unique'.
* Sat Apr 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.7:
  * decorate(1): new program - sorts input in non-standard ordering
    e.g. IPv4, IPv6, roman numerals.
  * New operations: sha224/sha384
  * New operations: geomean (Geometric mean) and harmmean (Harmonic
    mean)
- includes changes from 1.6:
  * The 'gutnum' operation now correctly prints detected numbers
    without truncating them
* Thu Sep 19 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.5:
  * accept backslash-escaped characters in field names
  * New operations for handling file names and paths
  * New getnum operation to extract a number from a string
  * New operation: cut, similar to cut(1)
* Wed Sep  4 2019 Michel Normand <normand@linux.vnet.ibm.com>
- disable LTO for ppc64 ppc64le aarch64 bypass boo#1149348
* Wed Dec 26 2018 astieger@suse.com
- update to 1.4:
  * New option: -C/--skip-comments to skip comment lines
- drop upsteamed patches:
  * upstream-disable-broken-test.patch
  * upstream-fix-test.patch
* Fri Mar 23 2018 guillaume.gardet@opensuse.org
- Disable broken test with upstream patch:
  * upstream-disable-broken-test.patch
- Fix another test
  * upstream-fix-test.patch
* Sat Mar 17 2018 astieger@suse.com
- initial package 1.3
